@@ -1,8 +1,10 @@
 """Time utils."""
 import time
 import datetime
+from pytz import timezone
 
 DEFAULT_TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
+DEFAULT_TZINFO = timezone('Asia/Colombo')
 
 
 def get_unixtime():
@@ -10,16 +12,26 @@ def get_unixtime():
     return (int)(time.time())
 
 
-def parse_time(time_str, time_format=DEFAULT_TIME_FORMAT):
+def parse_time(
+    time_str,
+    time_format=DEFAULT_TIME_FORMAT,
+    tzinfo=DEFAULT_TZINFO,
+):
     """Parse time string, and return unixtime."""
-    return (int)(time.mktime(
-        datetime.datetime.strptime(time_str, time_format).timetuple(),
-    ))
+    _datetime = datetime.datetime.strptime(time_str, time_format)
+    _datetime = _datetime.replace(tzinfo=tzinfo)
+    return (int)(time.mktime(_datetime.timetuple()))
 
 
-def format_time(unixtime, time_format=DEFAULT_TIME_FORMAT):
+def format_time(
+    unixtime,
+    time_format=DEFAULT_TIME_FORMAT,
+    tzinfo=DEFAULT_TZINFO,
+):
     """Format unixtime as time string."""
-    return datetime.datetime.fromtimestamp(unixtime).strftime(time_format)
+    _datetime = datetime.datetime.fromtimestamp(unixtime)
+    _datetime = _datetime.replace(tzinfo=tzinfo)
+    return _datetime.strftime(time_format)
 
 
 class StopWatch:
